==> apache-qpid-broker-j-7.1.12-src.tar.gz: apache-qpid-broker-j-7.1.12-src/broker-core/src/main/java/org/apache/qpid/server/security/auth/sasl/scram/ScramNegotiator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.server.security.auth.sasl.scram;

import org.apache.qpid.server.model.AuthenticationProvider;
import org.apache.qpid.server.security.auth.sasl.SaslNegotiator;
import org.apache.qpid.server.security.auth.sasl.AbstractSaslServerNegotiator;

public class ScramNegotiator extends AbstractSaslServerNegotiator implements SaslNegotiator
{
    private final ScramSaslServer _saslServer;
    private AuthenticationProvider<?> _authenticationProvider;

    public ScramNegotiator(final AuthenticationProvider<?> authenticationProvider,
                           final ScramSaslServerSource scramSaslServerSource,
                           final String mechanism)
    {
        _authenticationProvider = authenticationProvider;
        _saslServer = new ScramSaslServer(scramSaslServerSource, mechanism);
    }

    @Override
    protected AuthenticationProvider<?> getAuthenticationProvider()
    {
        return _authenticationProvider;
    }

    @Override
    protected Exception getSaslServerCreationException()
    {
        return null;
    }

    @Override
    protected ScramSaslServer getSaslServer()
    {
        return _saslServer;
    }

    @Override
    public String getAttemptedAuthenticationId()
    {
        return _saslServer.getAuthorizationID();
    }
}

==> apache-qpid-broker-j-9.2.1-src.tar.gz: apache-qpid-broker-j-9.2.1-src/broker-core/src/main/java/org/apache/qpid/server/security/auth/sasl/scram/ScramNegotiator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.server.security.auth.sasl.scram;

import org.apache.qpid.server.model.AuthenticationProvider;
import org.apache.qpid.server.security.auth.sasl.SaslNegotiator;
import org.apache.qpid.server.security.auth.sasl.AbstractSaslServerNegotiator;

public class ScramNegotiator extends AbstractSaslServerNegotiator implements SaslNegotiator
{
    private final ScramSaslServer _saslServer;
    private final AuthenticationProvider<?> _authenticationProvider;

    public ScramNegotiator(final AuthenticationProvider<?> authenticationProvider,
                           final ScramSaslServerSource scramSaslServerSource,
                           final String mechanism)
    {
        _authenticationProvider = authenticationProvider;
        _saslServer = new ScramSaslServer(scramSaslServerSource, mechanism);
    }

    @Override
    protected AuthenticationProvider<?> getAuthenticationProvider()
    {
        return _authenticationProvider;
    }

    @Override
    protected Exception getSaslServerCreationException()
    {
        return null;
    }

    @Override
    protected ScramSaslServer getSaslServer()
    {
        return _saslServer;
    }

    @Override
    public String getAttemptedAuthenticationId()
    {
        return _saslServer.getAuthorizationID();
    }
}
